"""write on file chain list for GE calculation.

This is use to parallelize computation.
"""
import ast
import csv
import pathlib


def read_modres_from_file(path_to_file):
    """Read modres from file."""
    out = {}
    for i in range(1, 7):
        with open(path_to_file / f"chains_modres_{i}.csv", "r") as infile:
            reader = csv.reader(infile)
            next(reader)
            next(reader)
            for row in reader:
                out[row[0]] = ast.literal_eval(row[1])
    return out


def write_chains_list(list2write, modres_dict):
    """Chains list for GE calculation."""
    with open(ge_dir / "chains_list.txt", "w") as outfile:
        writer = csv.writer(outfile)
        writer.writerow(["# generated by 0_prepare_chains_list.py"])
        writer.writerow(["# chain_id, chain_fix_path, has_modres, modres"])
        for row in list2write:
            chain_id = row.stem
            if chain_id in modres_dict:
                modres_list = modres_dict[chain_id]
                writer.writerow([chain_id, str(row), "yes", modres_list])
            else:
                writer.writerow([chain_id, str(row), "no"])


if __name__ == "__main__":
    membrane_dir = pathlib.Path("/mnt/MEMBRANE/")
    ge_dir = membrane_dir / "GE"
    pdb_dir = membrane_dir / "CHAINS_FIX"
    log_dir = membrane_dir / "CM/LOG"

    modres_dict = read_modres_from_file(log_dir)

    chain_path_fix = [
        path for path in pdb_dir.iterdir() if path.suffix == ".pdb"
    ]
    assert len(chain_path_fix) == 1282

    write_chains_list(chain_path_fix, modres_dict)
